@@ -1,35 +1,36 @@
 <?php
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog Forums Plugin 2.0 for Geeklog - The Ultimate Weblog
-// | Official release date: Feb 7,2003
+// | Geeklog Forums Plugin 2.0 for Geeklog - The Ultimate Weblog               |
+// | Official release date: Feb 7,2003                                         |
 // +---------------------------------------------------------------------------+
-// | japanese_utf-8.php ★もし万一エンコードがutf-8でなければ変換してください
+// | japanese_utf-8.php                                                        |
+// | Language defines for all text                                             |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000,2001 by the following authors: 
-// | Geeklog Author: Tony Bibbs       - tony@tonybibbs.com
+// | Copyright (C) 2000,2001 by the following authors:                         |
+// | Geeklog Author: Tony Bibbs       - tony@tonybibbs.com                     |
 // +---------------------------------------------------------------------------+
-// | FORUM Plugin Authors 
-// | Prototype & Concept    :  Mr.GxBlock of www.gxblock.com 
-// | Co-Developed by Matthew and Blaine
-// | Matthew DeWyer, contact: matt@mycws.com          www.cweb.ws
-// | Blaine Lang,    contact: geeklog@langfamily.ca   www.langfamily.ca
+// | FORUM Plugin Authors                                                      |
+// | Prototype & Concept    :  Mr.GxBlock of www.gxblock.com                   |
+// | Co-Developed by Matthew and Blaine                                        |
+// | Matthew DeWyer, contact: matt@mycws.com          www.cweb.ws              |
+// | Blaine Lang,    contact: geeklog@langfamily.ca   www.langfamily.ca        |
 // +---------------------------------------------------------------------------+
-// |  
-// | This program is free software; you can redistribute it and/or
-// | modify it under the terms of the GNU General Public License
-// | as published by the Free Software Foundation; either version 2 
-// | of the License, or (at your option) any later version.
-// | 
-// | This program is distributed in the hope that it will be useful, 
-// | but WITHOUT ANY WARRANTY; without even the implied warranty of
-// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// | GNU General Public License for more details.
-// | 
-// | You should have received a copy of the GNU General Public License
-// | along with this program; if not, write to the Free Software Foundation,
-// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-// | 
+// |                                                                           |
+// | This program is free software; you can redistribute it and/or             |
+// | modify it under the terms of the GNU General Public License               |
+// | as published by the Free Software Foundation; either version 2            |
+// | of the License, or (at your option) any later version.                    |
+// |                                                                           |
+// | This program is distributed in the hope that it will be useful,           |
+// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
+// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
+// | GNU General Public License for more details.                              |
+// |                                                                           |
+// | You should have received a copy of the GNU General Public License         |
+// | along with this program; if not, write to the Free Software Foundation,   |
+// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
+// |                                                                           |
 // +---------------------------------------------------------------------------+
 //
 # Tranlated by Geeklog Japanese group SaY and Ivy
@@ -64,7 +65,7 @@ $LANG_GF00 = array (
     'access_denied_msg' => 'Rootユーザのみこのページにアクセスできます。あなたの名前とIPアドレスは記録されました。',
     'admin'             => 'プラグイン管理者',
     'install_header'    => 'プラグインのインストール/アンインストール',
-    'installed'         => 'プラグインとブロックがインストールされました。<p><i>楽しんでください<br' . XHTML . '><a href="mailto:langmail@sympatico.ca">Blaine</a></i>',
+    'installed'         => 'プラグインとブロックがインストールされました。<p><em>楽しんでください<br' . XHTML . '><a href="mailto:langmail@sympatico.ca">Blaine</a></em>',
     'uninstalled'       => 'Forumプラグインはアンインストールされました。',
     'install_success'   => 'インストールは<p><b>次のステップへ</b>:   <ol><li>掲示板管理者は、新しく掲示板を開設してください。<li>掲示板の設定と個人の設定を再設定してください。 <li>少なくとも掲示板を1つ、カテゴリを1つ、作成してください。</ol> <p><a href="%s">インストールの注意</a> を再度ご覧ください。',
 
@@ -155,7 +156,7 @@ $LANG_GF01['OPTIONAL']       = '[オプション]';
 $LANG_GF01['SUBMIT']         = '保存';
 $LANG_GF01['PREVIEW']        = 'プレビュー';
 $LANG_GF01['NOTIFY']         = 'ご注意:';
-$LANG_GF01['REMOVE']         = '削除';
+$LANG_GF01['REMOVE']         = '解除';
 $LANG_GF01['KEYWORDS']       = 'キーワード';
 $LANG_GF01['EDIT']           = '編集';
 $LANG_GF01['DELETE']         = '削除';
@@ -183,10 +184,10 @@ $LANG_GF01['SUBMISSIONS']    = '投稿したもの';
 $LANG_GF01['HTML_FILTER_MSG']  = '一部のHTMLを許可';
 $LANG_GF01['HTML_FULL_MSG']  = 'すべてのHTMLを許可';
 $LANG_GF01['HTML_MSG']       = 'HTML許可';
-$LANG_GF01['CENSOR_PERM_MSG']  = 'バッドワードをチェック';
-$LANG_GF01['ANON_PERM_MSG']    = 'ゲストユーザの投稿を見る';
-$LANG_GF01['POST_PERM_MSG1']    = '投稿可能';
-$LANG_GF01['POST_PERM_MSG2']    = 'ゲストユーザ投稿可能';
+$LANG_GF01['CENSOR_PERM_MSG']= 'バッドワードをチェック';
+$LANG_GF01['ANON_PERM_MSG']  = 'ゲストユーザの投稿を見る';
+$LANG_GF01['POST_PERM_MSG1'] = '投稿可能';
+$LANG_GF01['POST_PERM_MSG2'] = 'ゲストユーザ投稿可能';
 $LANG_GF01['CENSORED']       = '検閲';
 $LANG_GF01['ALLOWED']        = '許可';
 $LANG_GF01['GO']             = '実行';
@@ -235,17 +236,18 @@ $LANG_GF01['ProfileLink']    = 'プロフィール';
 $LANG_GF01['WebsiteLink']    = 'ホームページ';
 $LANG_GF01['PMLink']         = 'PM';
 $LANG_GF01['EmailLink']      = 'メール';
-$LANG_GF01['FORUMSUBSCRIBE'] = '掲示板メール通知設定';
-$LANG_GF01['FORUMUNSUBSCRIBE'] = '掲示板メール通知設定解除';
+$LANG_GF01['FORUMSUBSCRIBE'] = 'メール通知を開始';
+$LANG_GF01['FORUMUNSUBSCRIBE'] = 'メール通知を解除';
+$LANG_GF01['FORUMSUBSCRIBE_TRUE'] = 'この掲示板のメール通知:有効';
+$LANG_GF01['FORUMSUBSCRIBE_FALSE'] = 'この掲示板のメール通知:無効';
 $LANG_GF01['NEWTOPIC']       = '新規投稿';
-$LANG_GF01['POSTREPLY']      = '投稿';
-$LANG_GF01['SubscribeLink']  = 'メール通知設定';
-$LANG_GF01['unSubscribeLink'] = 'メール通知設定解除';
-$LANG_GF01['FORUMSUBSCRIBE'] = '掲示板メール通知設定';
-$LANG_GF01['NEWTOPIC']       = 'トピック新規登録';
-$LANG_GF01['POSTREPLY']      = '新しく書き込む';
-$LANG_GF01['SUBSCRIPTIONS']  = 'メール通知設定リスト';
-$LANG_GF01['TOP']            = 'トピックトップ';
+$LANG_GF01['SubscribeLink_TRUE']  = 'このトピックのメール通知:有効';
+$LANG_GF01['SubscribeLink_FALSE'] = 'このトピックのメール通知:無効';
+$LANG_GF01['SubscribeLink']  = 'メール通知を開始';
+$LANG_GF01['unSubscribeLink'] = 'メール通知を解除';
+$LANG_GF01['POSTREPLY']      = '返信投稿';
+$LANG_GF01['SUBSCRIPTIONS']  = '投稿オプション';
+$LANG_GF01['TOP']            = 'トップ';
 $LANG_GF01['PRINTABLE']      = '印刷用ページ';
 $LANG_GF01['ForumProfile']   = '掲示板オプション';
 $LANG_GF01['USERPREFS']      = '掲示板のユーザ設定';
@@ -268,6 +270,7 @@ $LANG_GF01['INDEXPAGE']      = '掲示板目次';
 $LANG_GF01['FEATURE']        = '機能';
 $LANG_GF01['SETTING']        = '設定';
 $LANG_GF01['MARKALLREAD']    = 'すべて既読にする';
+$LANG_GF01['MSG_NO_CAT']     = 'カテゴリーまたは掲示板が定義されていません。';
 
 // Language for bbcode toolbar
 $LANG_GF01['CODE']           = 'コード';
@@ -315,7 +318,7 @@ $LANG_GF02['msg01']    = '申し訳ありませんが、掲示への参加には
 $LANG_GF02['msg02']    = '申し訳ありませんが、この掲示板への参加には登録が必要です。';
 $LANG_GF02['msg03']    = '';
 $LANG_GF02['msg04']    = '';
-$LANG_GF02['msg05']    = '<center><i>まだ登録されていません。</center></i>';
+$LANG_GF02['msg05']    = '<center><em>まだ登録されていません。</em></center>';
 $LANG_GF02['msg06']    = '最後の訪問以後の投稿';
 $LANG_GF02['msg07']    = 'オンラインユーザ:';
 $LANG_GF02['msg08']    = '<br' . XHTML . '><b>すべての登録ユーザの登録日時:</b> %s';
@@ -325,7 +328,7 @@ $LANG_GF02['msg11']    = '掲示板インデックスに戻る';
 $LANG_GF02['msg12']    = 'メインホームページに戻る';
 $LANG_GF02['msg13']    = '登録が必要です。';
 $LANG_GF02['msg14']    = '登録が必要です。<br' . XHTML . '>';
-$LANG_GF02['msg15']    = 'エラーだと思われたら、 <a href="mailto:%s?subject=Guestbook IP Ban">掲示板管理者</A>まで。';
+$LANG_GF02['msg15']    = 'エラーだと思われたら、 <a href="mailto:%s?subject=Guestbook IP Ban">掲示板管理者</a>まで。';
 $LANG_GF02['msg16']    = 'よくある投稿です。他の投稿や書き込みをご覧ください。';
 $LANG_GF02['msg17']    = 'メッセージ編集が完了しされました。';
 $LANG_GF02['msg18']    = 'エラー! 必須項目が入力されていないかまたは短すぎます。';
@@ -350,13 +353,13 @@ $LANG_GF02['msg34']    = 'メール:';
 $LANG_GF02['msg35']    = 'ホームページ:';
 $LANG_GF02['msg36']    = '気分アイコン:';
 $LANG_GF02['msg37']    = 'メッセージ:';
-$LANG_GF02['msg38']    = '新規書き込みをメールで通知　';
+$LANG_GF02['msg38']    = 'メール通知';
 $LANG_GF02['msg39']    = '<br' . XHTML . '>新規投稿レビューできません。';
-$LANG_GF02['msg40']    = '<br' . XHTML . '>既にメール通知設定されています。<br' . XHTML . '><br' . XHTML . '>';
+$LANG_GF02['msg40']    = '<br' . XHTML . '>既にメール通知に設定されています。<br' . XHTML . '><br' . XHTML . '>';
 $LANG_GF02['msg41']    = '<br' . XHTML . '> %s への投稿はメール通知設定されました。<br' . XHTML . '><br' . XHTML . '>';
-$LANG_GF02['msg42']    = 'メール通知設定を解除しました。';
-$LANG_GF02['msg43']    = 'このメール通知設定を解除してよいですか?.';
-$LANG_GF02['msg44']    = '<p style="margin:0px; padding:5px;">メール通知設定はありません</p>';
+$LANG_GF02['msg42']    = 'メール通知を解除しました。';
+$LANG_GF02['msg43']    = 'このメール通知を解除してよいですか?.';
+$LANG_GF02['msg44']    = '<p style="margin:0px; padding:5px;">メール通知が解除されています</p>';
 $LANG_GF02['msg45']    = '掲示板の検索';
 $LANG_GF02['msg46']    = '掲示板キーワード検索:';
 $LANG_GF02['msg47']    = '投稿者名を指定することもできます:';
@@ -388,12 +391,12 @@ $LANG_GF02['msg72']    = 'このメッセージがオンラインなら管理者
 $LANG_GF02['msg74']    = '最近の投稿 %s 件';
 $LANG_GF02['msg75']    = '閲覧数トップ %s 件';
 $LANG_GF02['msg76']    = '投稿数トップ %s 件';
-$LANG_GF02['msg77']    = '<br' . XHTML . '><p style="padding-left: 10px;">申し訳ありません。先にログインしてください。アカウントがなければ新規登録してください。<p />';
+$LANG_GF02['msg77']    = '<br' . XHTML . '><p style="padding-left: 10px;">申し訳ありません。先にログインしてください。アカウントがなければ新規登録してください。</p>';
 $LANG_GF02['msg78']    = '<br' . XHTML . '>ここに掲示板はありません。';
 $LANG_GF02['msg81']    = '- 投稿編集通知';
-$LANG_GF02['msg82']    = '<p>あなたのメッセージ "%s" は、モデーレータ %s によって編集されました。<p>';
-$LANG_GF02['msg83']    = '<br' . XHTML . '><br' . XHTML . '>掲示板のタイトルを入力してください。<p />';
-$LANG_GF02['msg84']    = 'すべて読んだことにする';
+$LANG_GF02['msg82']    = '<p>あなたのメッセージ "%s" は、モデーレータ %s によって編集されました。</p>';
+$LANG_GF02['msg83']    = '<br' . XHTML . '><br' . XHTML . '><p>掲示板のタイトルを入力してください。</p>';
+$LANG_GF02['msg84']    = '全て既読にする';
 $LANG_GF02['msg85']    = 'ページ:';
 $LANG_GF02['msg86']    = '最新 %s 投稿　投稿者: ';
 $LANG_GF02['msg87']    = '<br' . XHTML . '>警告:このトピックはロックされています。<br' . XHTML . '>追加の投稿はできません。';
@@ -410,12 +413,12 @@ $LANG_GF02['msg106']   = '掲示板を選択';
 $LANG_GF02['msg107']   = '掲示板テーマ:';
 $LANG_GF02['msg108']   = '新規投稿のある掲示板';
 $LANG_GF02['msg109']   = 'ロックされたトピック';
-$LANG_GF02['msg110']   = '編集ページに移動中..';
+$LANG_GF02['msg110']   = '編集ページに移動中...';
 $LANG_GF02['msg111']   = '未読リスト:';
 $LANG_GF02['msg112']   = '未読を表示する';
 $LANG_GF02['msg113']   = '未読を表示する';
 $LANG_GF02['msg114']   = 'ロック済';
-$LANG_GF02['msg115']   = '注目トピック新着';
+$LANG_GF02['msg115']   = '注目トピック 新着';
 $LANG_GF02['msg116']   = 'ロック済トピック 新着';
 $LANG_GF02['msg117']   = 'サイト検索';
 $LANG_GF02['msg118']   = '掲示板検索';
@@ -426,27 +429,27 @@ $LANG_GF02['msg122']   = '人気順リスト件数';
 $LANG_GF02['msg123']   = '人気順リストに表示する件数';
 $LANG_GF02['msg124']   = '1ページごとのメッセージ数';
 $LANG_GF02['msg125']   = 'モデレータのみ: メッセージ一覧画面';
-$LANG_GF02['msg126']   = '検索ライン:';
+$LANG_GF02['msg126']   = '検索ライン';
 $LANG_GF02['msg127']   = '探索結果に表示するラインの数';
-$LANG_GF02['msg128']   = '投稿者数/1ページ:';
+$LANG_GF02['msg128']   = '投稿者数/1ページ';
 $LANG_GF02['msg129']   = '投稿者リストの1ページに表示する人数';
-$LANG_GF02['msg130']   = 'ゲストユーザ投稿表示:';
+$LANG_GF02['msg130']   = 'ゲストユーザ投稿表示';
 $LANG_GF02['msg131']   = 'ゲストユーザ投稿を表示する';
-$LANG_GF02['msg132']   = 'メール通知設定モード:';
+$LANG_GF02['msg132']   = 'メール通知モード';
 $LANG_GF02['msg133']   = '書き込みがあればメール通知を既定値にする';
-$LANG_GF02['msg134']   = '投稿が追加されました。';
-$LANG_GF02['msg135']   = 'あなたの全ての投稿が掲示板に通知されます';
+$LANG_GF02['msg134']   = 'メール通知を開始しました。';
+$LANG_GF02['msg135']   = 'この掲示板への全ての投稿があなたに通知されます。';
 $LANG_GF02['msg136']   = '投稿先の掲示板を選んでください。';
 $LANG_GF02['msg137']   = '書き込みがあればメールで通知されます。';
 $LANG_GF02['msg138']   = '<b>掲示板全体</b>';
 $LANG_GF02['msg139']   = '%s 続ける場合は<a href="%s">クリック</a>';
 $LANG_GF02['msg140']   = '続ける';
 $LANG_GF02['msg141']   = 'このページは自動的に戻ります。戻らない場合は <a href="%s">こちら</a>';
-$LANG_GF02['msg142']   = 'メール通知設定モードに変更しました。';
+$LANG_GF02['msg142']   = 'メール通知を開始しました。';
 $LANG_GF02['msg143']   = '通知';
 $LANG_GF02['msg144']   = 'トピックへ';
 $LANG_GF02['msg145']   = 'スレッド参照';
-$LANG_GF02['msg146']   = 'メール通知設定モードは解除されました。';
+$LANG_GF02['msg146']   = 'メール通知を解除しました。';
 $LANG_GF02['msg147']   = '掲示板の印刷';
 $LANG_GF02['msg148']   = '<a href="javascript:history.back()">戻る</a>';
 $LANG_GF02['msg149']   = ' %s インスタントメッセージを送ってください。';
@@ -462,10 +465,10 @@ $LANG_GF02['msg158']   = '最新10投稿者 ';
 $LANG_GF02['msg159']   = 'モデレータのデータを本当に削除してもよいですか？';
 $LANG_GF02['msg160']   = '投稿の最後のページを見る';
 $LANG_GF02['msg161']   = 'メンバーリストへ戻る';
-$LANG_GF02['msg162']   = '<a href="%s">こちら</a><br' . XHTML . '><p>へ自動的に戻りますが、すぐに戻りたい場合は <a href="%s">こちら</a>';
-$LANG_GF02['msg163']   = '投稿が移動しました';
-$LANG_GF02['msg164']   = 'すべて読んだことにする';
-$LANG_GF02['msg165']   = 'エラー：<p>マッチする <b>引用</b> タグがありません。フォーマットできません。</p>';
+$LANG_GF02['msg162']   = '<a href="%s">こちら</a><br' . XHTML . '>へ自動的に戻りますが、すぐに戻りたい場合は <a href="%s">こちら</a>';
+$LANG_GF02['msg163']   = '投稿を移動しました。';
+$LANG_GF02['msg164']   = '全て既読にする';
+$LANG_GF02['msg165']   = '<p>エラー: マッチする <b>引用</b> タグがありません。フォーマットできません。</p>';
 $LANG_GF02['msg166']   = 'エラー: 記事が壊れたか、見つかりません。';
 $LANG_GF02['msg167']   = '通知オプション';
 $LANG_GF02['msg168']   = 'メール通知を無効にする';
@@ -686,7 +689,7 @@ $LANG_GF92 = array (
     'all_topics'         => 'すべて',
     'no_topic'           => 'ホームページのみ',
     'position_top'       => 'ページのトップ',
-    'position_feat'      => '特集記事のあと',
+    'position_feat'      => '注目記事のあと',
     'position_bottom'    => 'ページのボトム',
     'messagespp'         => '1ページごとのメッセージ数',
     'messagesppdscp'     => 'メッセージ管理画面 - 1ページごとのメッセージ数',
@@ -699,7 +702,7 @@ $LANG_GF92 = array (
     'minsubjectlength'   => '最小件名長',
     'minsubjectdscp'     => '件名の最小の長さ',
     'popular'            => '一般的な投稿',
-    'populardscp'        => '閲覧回数',
+    'populardscp'        => '閲覧数',
     'convertbreak'       => '改行変換',
     'convertbreakdscp'   => '改行をHTMLタグ(&lt;br&gt;)に変換する',
     'speedlimit'         => '投稿間隔制限',
@@ -745,19 +748,19 @@ $LANG_GF93 = array (
     'forumaddError'      => '掲示板追加エラー',
     'forumdeleted'       => '掲示板が削除されました。',
     'forumedited'        => '掲示板が更新されました。',
-    'forumordered'       => '掲示板の順番を編集',
+    'forumordered'       => '掲示板の順番を更新しました。',
     'transfer'           => '移動中..',
     'vieworder'          => 'View Order',
     'back'               => '戻る',
     'addnote'            => '注意: これらの変数を編集できます。',
     'editnote'           => '掲示板の詳細を編集: ',
     'editforumnote'      => '編集: <b>"%s"</b>',
-    'deleteforumnote1'   => '<b>"%s"</b>&nbsp;削除してもよろしいですか ?',
+    'deleteforumnote1'   => '掲示板&nbsp;<b>"%s"</b>&nbsp;を削除してもよろしいですか ?',
     'editcatnote'        => '編集: <b>"%s"</b>',
-    'deletecatnote1'     => '<b>"%s"</b>&nbsp;削除してもよろしいですか ?',
+    'deletecatnote1'     => 'カテゴリー&nbsp;<b>"%s"</b>&nbsp;を削除してもよろしいですか ?',
     'deletecatnote2'     => 'このカテゴリーのすべての掲示板とトピックも削除されます。',
     'undercat'           => 'カテゴリー:',
-    'deleteforumnote2'   => 'その直下の投稿はすべて削除されます。',
+    'deleteforumnote2'   => 'この掲示板に属する全てのトピックも削除されます。',
     'groupaccess'        => 'グループ: ',
     'rebuild'            => '最新の投稿テーブルを修正',
     'action'             => 'アクション',
@@ -797,7 +800,7 @@ $LANG_GF94 = array (
     'deletemsg'          => '(注意: このボタンをクリックするとすぐ削除されます。)',
     'username'           => 'ユーザ名:',
     'forforum'           => '掲示板用:',
-    'modper'             => 'アクセス権限:',
+    'modper'             => 'アクセス権:',
     'candelete'          => '削除可能:',
     'canban'             => '禁止可能:',
     'canedit'            => '編集可能:',
