@@ -33,34 +33,39 @@
 // +---------------------------------------------------------------------------+
 //
 
-require_once("../lib-common.php"); // Path to your lib-common.php
-require_once ($_CONF['path_html'] . 'forum/include/gf_format.php');
-require_once($_CONF['path'] . 'plugins/forum/debug.php');  // Common Debug Code
-//need function forum_mb_wordwrap
-require_once($_CONF['path'] . 'plugins/forum/functions.inc');
+require_once '../lib-common.php'; // Path to your lib-common.php
+require_once $CONF_FORUM['path_include'] . 'gf_format.php';
 
-// Pass thru filter any get or post variables to only allow numeric values and remove any hostile data
-$forum = COM_applyFilter($_REQUEST['forum'],true);
-$show = COM_applyFilter($_REQUEST['show'],true);
-$page = COM_applyFilter($_REQUEST['page'],true);
-$order = COM_applyFilter($_REQUEST['order'],true);
-$prevorder = COM_applyFilter($_REQUEST['prevorder']);
-$direction = COM_applyFilter($_REQUEST['direction']);
-$sort = COM_applyFilter($_REQUEST['sort'],true);
-$cat_id = COM_applyFilter($_REQUEST['cat_id'],true);
-$op = COM_applyFilter($_REQUEST['op']);
-
-//Check is anonymous users can access
-if ($CONF_FORUM['registration_required'] && $_USER['uid'] < 2) {
-    echo COM_siteHeader();
-    echo COM_startBlock();
-    alertMessage($LANG_GF02['msg01'],$LANG_GF02['msg171']);
-    echo COM_endBlock();
-    echo COM_siteFooter();
+if (!in_array('forum', $_PLUGINS)) {
+    echo COM_refresh($_CONF['site_url'] . '/index.php');
     exit;
 }
 
-$todaysdate=date($_CONF['shortdate']);
+// Pass thru filter any get or post variables to only allow numeric values and remove any hostile data
+$forum     = COM_applyFilter($_REQUEST['forum'],true);
+$show      = COM_applyFilter($_REQUEST['show'],true);
+$page      = COM_applyFilter($_REQUEST['page'],true);
+$order     = COM_applyFilter($_REQUEST['order'],true);
+$prevorder = COM_applyFilter($_REQUEST['prevorder']);
+$direction = COM_applyFilter($_REQUEST['direction']);
+$sort      = COM_applyFilter($_REQUEST['sort'],true);
+$cat_id    = COM_applyFilter($_REQUEST['cat_id'],true);
+$op        = COM_applyFilter($_REQUEST['op']);
+
+$display = '';
+
+//Check is anonymous users can access
+if ($CONF_FORUM['registration_required'] && $_USER['uid'] < 2) {
+    $display .= COM_siteHeader();
+    $display .= COM_startBlock();
+    $display .= alertMessage($LANG_GF02['msg01'],$LANG_GF02['msg171']);
+    $display .= COM_endBlock();
+    $display .= COM_siteFooter();
+    COM_output($display);
+    exit;
+}
+
+$todaysdate = date($_CONF['shortdate']);
 
 // Check to see if request to mark all topics read was requested
 if ($_USER['uid'] > 1 && $op == 'markallread') {
@@ -77,7 +82,7 @@ if ($_USER['uid'] > 1 && $op == 'markallread') {
 
     foreach ($categories as $category) {
         $fsql = DB_query("SELECT forum_id,grp_id FROM {$_TABLES['gf_forums']} WHERE forum_cat=$category");
-        while($frecord = DB_fetchArray($fsql)){
+        while ($frecord = DB_fetchArray($fsql)) {
             $groupname = DB_getItem($_TABLES['groups'],'grp_name',"grp_id='{$frecord['grp_id']}'");
             if (SEC_inGroup($groupname)) {
                 DB_query("DELETE FROM {$_TABLES['gf_log']} WHERE uid=$_USER[uid] AND forum={$frecord['forum_id']}");
@@ -95,21 +100,39 @@ if ($_USER['uid'] > 1 && $op == 'markallread') {
     exit();
 }
 
-// Display Common headers
-ob_start();
-echo gf_siteHeader();
-
 //Check if anonymous users allowed to access forum
 forum_chkUsercanAccess();
 
+//ob_start();
+// Display Common headers
+$display .= gf_siteHeader();
+
+// Debug Code to show variables
+$display .= gf_showVariables();
+
+$msg = '';
+if (isset($_GET['msg'])) {
+    $msg = COM_applyFilter($_GET['msg'], true);
+}
+if ($msg==1) {
+    $display .= COM_showMessageText($LANG_GF02['msg134'] . "<br" . XHTML . ">" . $LANG_GF02['msg135']);
+}
+if ($msg==2) {
+    $display .= COM_showMessageText($LANG_GF02['msg166']);
+}
+if ($msg==3) {
+    $display .= COM_showMessageText($LANG_GF02['msg55']);
+}
+
 if ($op == 'newposts' AND $_USER['uid'] > 1) {
-    $report = new Template($_CONF['path_layout'] . 'forum/layout');
-    $report->set_file (array ('report' => 'reports/report_results.thtml',
-                    'records' => 'reports/report_record.thtml',
-                    'outline_header'=>'forum_outline_header.thtml',
+    $report = new Template($CONF_FORUM['path_layout'] . 'forum/layout');
+    $report->set_file (array (
+                    'report'         => 'reports/report_results.thtml',
+                    'records'        => 'reports/report_record.thtml',
+                    'outline_header' => 'forum_outline_header.thtml',
                     'outline_footer' => 'forum_outline_footer.thtml',
-                    'markread' => 'links/markread.thtml',
-                    'return' => 'links/return.thtml'));
+                    'markread'       => 'links/markread.thtml',
+                    'return'         => 'links/return.thtml'));
 
     switch($order) {
         case 1:
@@ -137,7 +160,7 @@ if ($op == 'newposts' AND $_USER['uid'] > 1) {
 
     $report->set_var ('xhtml', XHTML);
     $report->set_var ('imgset', $CONF_FORUM['imgset']);
-    $report->set_var ('layout_url', $_CONF['layout_url']);
+    $report->set_var ('layout_url', $CONF_FORUM['layout_url']);
     $report->set_var ('phpself',$_CONF['site_url'] . '/forum/index.php?op=newposts');
     $report->set_var ('LANG_TITLE', $LANG_GF02['msg111']);
     $report->set_var ('startblock', COM_startBlock($LANG_GF02['msg111']));
@@ -204,7 +227,7 @@ if ($op == 'newposts' AND $_USER['uid'] > 1) {
                     $report->set_var('post_replies', $P['replies']);
                     $report->set_var('post_views', $P['views']);
                     $report->parse ('report_records', 'records',true);
-                    if($csscode == 2) {
+                    if ($csscode == 2) {
                         $csscode = 1;
                     } else {
                         $csscode++;
@@ -226,19 +249,21 @@ if ($op == 'newposts' AND $_USER['uid'] > 1) {
     }
 
     $report->parse ('output', 'report');
-    echo $report->finish ($report->get_var('output'));
+    $display .= $report->finish ($report->get_var('output'));
     // Display Common headers
-    gf_siteFooter();
+    $display .= gf_siteFooter();
+    COM_output($display);
     exit();
 }
 
 if ($op == 'search') {
-    $report = new Template($_CONF['path_layout'] . 'forum/layout');
-    $report->set_file (array ('report' => 'reports/report_results.thtml',
-                    'records' => 'reports/report_record.thtml',
-                    'outline_header'=>'forum_outline_header.thtml',
+    $report = new Template($CONF_FORUM['path_layout'] . 'forum/layout');
+    $report->set_file (array (
+                    'report'         => 'reports/report_results.thtml',
+                    'records'        => 'reports/report_record.thtml',
+                    'outline_header' => 'forum_outline_header.thtml',
                     'outline_footer' => 'forum_outline_footer.thtml',
-                    'return' => 'links/return.thtml'));
+                    'return'         => 'links/return.thtml'));
 
     switch($order) {
         case 1:
@@ -268,7 +293,7 @@ if ($op == 'search') {
 
     $report->set_var ('xhtml', XHTML);
     $report->set_var ('imgset', $CONF_FORUM['imgset']);
-    $report->set_var ('layout_url', $_CONF['layout_url']);
+    $report->set_var ('layout_url', $CONF_FORUM['layout_url']);
     $report->set_var ('phpself',$_CONF['site_url'] . '/forum/index.php?op=search');
     $report->set_var ('LANG_TITLE',$LANG_GF02['msg119']. ' ' .$query);
     $report->set_var ('startblock', COM_startBlock( $LANG_GF02['msg119']. ' ' .$query));
@@ -328,7 +353,7 @@ if ($op == 'search') {
                 $report->set_var('post_views', $P['views']);
                 $report->set_var ('csscode', $csscode);
                 $report->parse ('report_records', 'records',true);
-                if($csscode == 2) {
+                if ($csscode == 2) {
                     $csscode = 1;
                 } else {
                     $csscode++;
@@ -345,20 +370,22 @@ if ($op == 'search') {
         $report->set_var ('bottomlink',$link);
     }
     $report->parse ('output', 'report');
-    echo $report->finish($report->get_var('output'));
+    $display .= $report->finish($report->get_var('output'));
     // Display Common headers
-    gf_siteFooter();
+    $display .= gf_siteFooter();
+    COM_output($display);
     exit();
 }
 
 if ($op == 'popular') {
 
-    $report = new Template($_CONF['path_layout'] . 'forum/layout');
-    $report->set_file (array ('report' => 'reports/report_results.thtml',
-                    'records' => 'reports/report_record.thtml',
-                    'outline_header'=>'forum_outline_header.thtml',
+    $report = new Template($CONF_FORUM['path_layout'] . 'forum/layout');
+    $report->set_file (array (
+                    'report'         => 'reports/report_results.thtml',
+                    'records'        => 'reports/report_record.thtml',
+                    'outline_header' => 'forum_outline_header.thtml',
                     'outline_footer' => 'forum_outline_footer.thtml',
-                    'return' => 'links/return.thtml'));
+                    'return'         => 'links/return.thtml'));
 
     switch($order) {
         case 1:
@@ -391,7 +418,7 @@ if ($op == 'popular') {
 
     $report->set_var ('xhtml', XHTML);
     $report->set_var ('imgset', $CONF_FORUM['imgset']);
-    $report->set_var ('layout_url', $_CONF['layout_url']);
+    $report->set_var ('layout_url', $CONF_FORUM['layout_url']);
     $report->set_var ('phpself',$_CONF['site_url'] . '/forum/index.php?op=popular');
     $report->set_var ('endblock', COM_endBlock());
     $report->set_var ('spacerwidth', '70%');
@@ -417,7 +444,7 @@ if ($op == 'popular') {
     $result = DB_query("SELECT date,subject,comment,replies,views,id,forum FROM {$_TABLES['gf_topic']} WHERE (pid = '0') ORDER BY $orderby $direction");
     $nrows = DB_numRows($result);
     $displayrecs = 0;
-    for ($i = 1; $i <= $nrows; $i++) {
+    for ($i = 0; $i < $nrows; $i++) {
         $P = DB_fetchArray($result);
         $forumgrpid = DB_getItem($_TABLES['gf_forums'],'grp_id',"forum_id='{$P['forum']}'");
         $groupname = DB_getItem($_TABLES['groups'],'grp_name',"grp_id='$forumgrpid'");
@@ -447,9 +474,10 @@ if ($op == 'popular') {
         $report->set_var ('bottomlink',$link);
     }
     $report->parse ('output', 'report');
-    echo $report->finish($report->get_var('output'));
+    $display .= $report->finish($report->get_var('output'));
     // Display Common headers
-    gf_siteFooter();
+    $display .= gf_siteFooter();
+    COM_output($display);
     exit();
 }
 
@@ -458,18 +486,22 @@ if ($op == 'subscribe') {
         DB_query("INSERT INTO {$_TABLES['gf_watch']} (forum_id,topic_id,uid,date_added) VALUES ('$forum','0','{$_USER['uid']}', now() )");
         // Delete all individual topic notification records
         DB_query("DELETE FROM {$_TABLES['gf_watch']} WHERE uid='{$_USER['uid']}' AND forum_id='$forum' and topic_id > '0' " );
-        forum_statusMessage($LANG_GF02['msg134'],$_CONF['site_url'] .'/forum/index.php?forum=' .$forum,$LANG_GF02['msg135']);
+//        $display .= forum_statusMessage($LANG_GF02['msg134'],$_CONF['site_url'] .'/forum/index.php?forum=' .$forum,$LANG_GF02['msg135']);
+        $display = COM_refresh($_CONF['site_url'] .'/forum/index.php?msg=1&amp;forum=' .$forum);
+        COM_output($display);
+        exit();
     } else {
-        BlockMessage($LANG_GF01['ERROR'],$LANG_GF02['msg136'],false);
+        $display .= BlockMessage($LANG_GF01['ERROR'],$LANG_GF02['msg136'],false);
     }
     // Display Common headers
-    gf_siteFooter();
+    $display .= gf_siteFooter();
+    COM_output($display);
     exit();
 }
 
 // MAIN CODE BEGINS to view forums or topics within a forum
 
-ForumHeader($forum,$showtopic);
+ForumHeader($forum,$showtopic,$display);
 
 // Check if the number of records was specified to show - part of page navigation.
 // Will be 0 if not set - as I'm now passing this tru gf_applyFilte() at top of script
@@ -484,11 +516,11 @@ if ($page == 0) {
     $page = 1;
 }
 
-if($forum > 0) {
+if ($forum > 0) {
     $addforumvar = "&amp;forum=" .$forum;
     $topiclistsql = DB_query("SELECT * FROM {$_TABLES['gf_topic']} WHERE pid=0 and forum='$forum'");
 } else {
-   $topiclistsql = DB_query("SELECT * FROM {$_TABLES['gf_topic']} WHERE pid=0");
+    $topiclistsql = DB_query("SELECT * FROM {$_TABLES['gf_topic']} WHERE pid=0");
 }
 
 $topicCount = DB_numRows($topiclistsql);
@@ -512,21 +544,22 @@ if ($forum == 0) {
 
     $categoryQuery = DB_query("SELECT * FROM {$_TABLES['gf_categories']} ORDER BY cat_order ASC");
     $numCategories = DB_numRows($categoryQuery);
-    $forumlisting = new Template($_CONF['path_layout'] . 'forum/layout');
+    $forumlisting = new Template($CONF_FORUM['path_layout'] . 'forum/layout');
 
-    $forumlisting->set_file (array ('forumlisting' => 'homepage.thtml',
-            'forum_outline_header'=>'forum_outline_header.thtml',
-            'forum_outline_footer'=>'forum_outline_footer.thtml',
-            'newposts' => 'links/newposts.thtml',
-            'markread' => 'links/markread.thtml',
-            'forum_record'=>'forumlisting_record.thtml',
-            'category_record'=>'categorylisting.thtml' ));
+    $forumlisting->set_file (array (
+            'forumlisting'         => 'homepage.thtml',
+            'forum_outline_header' => 'forum_outline_header.thtml',
+            'forum_outline_footer' => 'forum_outline_footer.thtml',
+            'newposts'             => 'links/newposts.thtml',
+            'markread'             => 'links/markread.thtml',
+            'forum_record'         => 'forumlisting_record.thtml',
+            'category_record'      => 'categorylisting.thtml' ));
 
     $forumlisting->set_var ('xhtml', XHTML);
     $forumlisting->set_var ('imgset', $CONF_FORUM['imgset']);
-    $forumlisting->set_var ('forumindeximg','<img src="'.gf_getImage('forumindex').'">');
+    $forumlisting->set_var ('forumindeximg','<img alt="forum index" src="'.gf_getImage('forumindex').'"' . XHTML . '>');
     $forumlisting->set_var ('phpself', $_CONF['site_url'] .'/forum/index.php');
-    $forumlisting->set_var('layout_url', $_CONF['layout_url']);
+    $forumlisting->set_var('layout_url', $CONF_FORUM['layout_url']);
     $viewnewpostslink = false;  // Set true when we have set the view newposts link template var
 
     for ($i=1; $i <= $numCategories; $i++) {
@@ -567,13 +600,13 @@ if ($forum == 0) {
                             if ($showmods['mod_groupid'] > 0) {
                                 $showmods['mod_username'] = DB_getItem($_TABLES['groups'], 'grp_name', "grp_id='{$showmods['mod_groupid']}'");
                             }
-                            if($moderatorcnt == 1 OR $moderators == '') {
+                            if ($moderatorcnt == 1 OR $moderators == '') {
                                 $moderators = $showmods['mod_username'];
                             } else {
                                 $moderators .= ', ' . $showmods['mod_username'];
                             }
                         } else {
-                            if($moderatorcnt == 1 OR $moderators == '') {
+                            if ($moderatorcnt == 1 OR $moderators == '') {
                                 $moderators = COM_getDisplayName($showmods['mod_uid']);
                             } else {
                                 $moderators .= ', ' . COM_getDisplayName($showmods['mod_uid']);
@@ -597,12 +630,12 @@ if ($forum == 0) {
                     // Determine if there are new topics since last visit for this user.
                     $lsql = DB_query("SELECT * FROM {$_TABLES['gf_log']} WHERE uid='{$_USER['uid']}' AND forum='{$B['forum_id']}' AND time > 0");
                     if ($topicCount > DB_numRows($lsql)) {
-                        $folderimg = '<img src="'.gf_getImage('busyforum').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg111'].'" title="'.$LANG_GF02['msg111'].'">';
+                        $folderimg = '<img src="'.gf_getImage('busyforum').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg111'].'" title="'.$LANG_GF02['msg111'].'"' . XHTML . '>';
                     } else {
-                        $folderimg = '<img src="'.gf_getImage('quietforum').'" border="0" align="absmiddle" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'">';
+                        $folderimg = '<img src="'.gf_getImage('quietforum').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'"' . XHTML . '>';
                     }
                 } else {
-                    $folderimg = '<img src="'.gf_getImage('quietforum').'" border="0" align="absmiddle" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'">';
+                    $folderimg = '<img src="'.gf_getImage('quietforum').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'"' . XHTML . '>';
                 }
 
                 $lastdate1 = strftime('%d', $B['date']);
@@ -617,7 +650,7 @@ if ($forum == 0) {
                 }
 
                 $lastpostmsgDate  = '<span class="forumtxt">' . $LANG_GF01['ON']. '</span>' .$lastdate;
-                if($B['uid'] > 1) {
+                if ($B['uid'] > 1) {
                     $lastposterName = COM_getDisplayName($B['uid']);
                     $by = '<a href="' .$_CONF['site_url']. '/users.php?mode=profile&amp;uid=' .$B['uid']. '">' .$lastposterName. '</a>';
                 } else {
@@ -632,7 +665,7 @@ if ($forum == 0) {
                 $forumlisting->set_var ('lastpostmsgDate', $LANG_GF01['nolastpostmsg']);
                 $forumlisting->set_var ('lastpostmsgTopic', '');
                 $forumlisting->set_var ('lastpostmsgBy', '');
-                $folderimg = '<img src="'.gf_getImage('quietforum').'" border="0" align="absmiddle" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'">';
+                $folderimg = '<img src="'.gf_getImage('quietforum').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['quietforum'].'" title="'.$LANG_GF02['quietforum'].'"' . XHTML . '>';
             }
 
             if ($B['pid'] == 0) {
@@ -678,14 +711,14 @@ if ($forum == 0) {
 
     }
 
-    if ($numCategories == 0 ) {         // Do we have any categories defined yet
-        echo '<h1 style="padding:10px; color:#F00; background-color:#000">No Categories or Forums Defined</h1>';
+    if ($numCategories == 0) {         // Do we have any categories defined yet
+        $display .= '<p style="padding:10px; color:#DF000D; background-color:#FFF7D9; border:solid #FFDA35 1px; font-weight:bold">' . $LANG_GF01['MSG_NO_CAT'] . '</p>';
     }
 
     $forumlisting->parse ('outline_header', 'forum_outline_header');
     $forumlisting->parse ('outline_footer', 'forum_outline_footer');
     $forumlisting->parse ('output', 'forumlisting');
-    echo $forumlisting->finish ($forumlisting->get_var('output'));
+    $display .= $forumlisting->finish ($forumlisting->get_var('output'));
 
     //$exectime = $mytimer->stopTimer();
     //COM_errorLog("End of Listing - time:$exectime");
@@ -694,35 +727,36 @@ if ($forum == 0) {
  // Display Forums
 if ($forum > 0) {
 
-    $topiclisting = new Template($_CONF['path_layout'] . 'forum/layout');
-    $topiclisting->set_file (array ('topiclisting' => 'topiclisting.thtml',
-            'forum_outline_header'=>'forum_outline_header.thtml',
-            'forum_outline_footer'=>'forum_outline_footer.thtml',
-            'subscribe' => 'links/subscribe_forum.thtml',
-            'new' => 'links/newtopic.thtml',
-            'topic_record'=>'topiclist_record.thtml' ));
+    $topiclisting = new Template($CONF_FORUM['path_layout'] . 'forum/layout');
+    $topiclisting->set_file (array (
+            'topiclisting'         => 'topiclisting.thtml',
+            'forum_outline_header' => 'forum_outline_header.thtml',
+            'forum_outline_footer' => 'forum_outline_footer.thtml',
+            'subscribe'            => 'links/subscribe_forum.thtml',
+            'new'                  => 'links/newtopic.thtml',
+            'topic_record'         => 'topiclist_record.thtml' ));
 
     $topiclisting->set_var ('xhtml', XHTML);
     $topiclisting->set_var ('imgset', $CONF_FORUM['imgset']);
-    $topiclisting->set_var('layout_url', $_CONF['layout_url']);
-    $topiclisting->set_var('site_url',$_CONF['site_url']);
+    $topiclisting->set_var ('layout_url', $CONF_FORUM['layout_url']);
+    $topiclisting->set_var ('site_url',$_CONF['site_url']);
     $topiclisting->set_var ('LANG_HOME', $LANG_GF01['HOMEPAGE']);
-    $topiclisting->set_var('forum_home',$LANG_GF01['INDEXPAGE']);
-    $topiclisting->set_var ('navbreadcrumbsimg','<img src="'.gf_getImage('nav_breadcrumbs').'">');
-    $topiclisting->set_var ('img_asc1', '<img src="'.gf_getImage('asc').'" border="0">');
-    $topiclisting->set_var ('img_asc2', '<img src="'.gf_getImage('asc').'" border="0">');
-    $topiclisting->set_var ('img_asc3', '<img src="' .$CONF_FORUM['imgset']. '/asc.gif" border="0">');
-    $topiclisting->set_var ('img_asc4', '<img src="'.gf_getImage('asc').'" border="0">');
-    $topiclisting->set_var ('img_asc5', '<img src="'.gf_getImage('asc').'" border="0">');
-    $topiclisting->set_var ('img_desc1', '<img src="'.gf_getImage('desc').'" border="0">');
-    $topiclisting->set_var ('img_desc2', '<img src="'.gf_getImage('desc').'" border="0">');
-    $topiclisting->set_var ('img_desc3', '<img src="'.gf_getImage('desc').'" border="0">');
-    $topiclisting->set_var ('img_desc4', '<img src="'.gf_getImage('desc').'" border="0">');
-    $topiclisting->set_var ('img_desc5', '<img src="'.gf_getImage('desc').'" border="0">');
+    $topiclisting->set_var ('forum_home',$LANG_GF01['INDEXPAGE']);
+    $topiclisting->set_var ('navbreadcrumbsimg','<img alt="" src="'.gf_getImage('nav_breadcrumbs').'"' . XHTML . '>');
+    $topiclisting->set_var ('img_asc1', '<img alt="" src="'.gf_getImage('asc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_asc2', '<img alt="" src="'.gf_getImage('asc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_asc3', '<img alt="" src="' .$CONF_FORUM['imgset']. '/asc.gif" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_asc4', '<img alt="" src="'.gf_getImage('asc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_asc5', '<img alt="" src="'.gf_getImage('asc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_desc1', '<img alt="" src="'.gf_getImage('desc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_desc2', '<img alt="" src="'.gf_getImage('desc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_desc3', '<img alt="" src="'.gf_getImage('desc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_desc4', '<img alt="" src="'.gf_getImage('desc').'" style="border:none;"' . XHTML . '>');
+    $topiclisting->set_var ('img_desc5', '<img alt="" src="'.gf_getImage('desc').'" style="border:none;"' . XHTML . '>');
 
-    if(function_exists(prj_getSessionProject)) {
+    if (function_exists(prj_getSessionProject)) {
         $projectid = prj_getSessionProject();
-        if($projectid > 0) {
+        if ($projectid > 0) {
             $link = "<a href=\"{$_CONF['site_url']}/projects/viewproject.php?pid=$projectid\">{$strings['RETURN2PROJECT']}</a>";
             $topiclisting->set_var ('return2project',$link);
         }
@@ -730,53 +764,53 @@ if ($forum > 0) {
 
     switch($sort) {
         case 1:
-            if($order == 0) {
+            if ($order == 0) {
                 $sortOrder = "subject ASC";
-                $topiclisting->set_var ('img_asc1', '<img src="'.gf_getImage('asc_on').'" border="0">');
+                $topiclisting->set_var ('img_asc1', '<img alt="" src="'.gf_getImage('asc_on').'" style="border:none;"' . XHTML . '>');
             } else {
                 $sortOrder = "subject DESC";
-                $topiclisting->set_var ('img_desc1', '<img src="'.gf_getImage('desc_on').'" border="0">');
+                $topiclisting->set_var ('img_desc1', '<img alt="" src="'.gf_getImage('desc_on').'" style="border:none;"' . XHTML . '>');
             }
             break;
         case 2:
-            if($order == 0) {
+            if ($order == 0) {
                 $sortOrder = "views ASC";
-                $topiclisting->set_var ('img_asc2', '<img src="'.gf_getImage('asc_on').'" border="0">');
+                $topiclisting->set_var ('img_asc2', '<img alt="" src="'.gf_getImage('asc_on').'" style="border:none;"' . XHTML . '>');
             } else {
                 $sortOrder = "views DESC";
-                $topiclisting->set_var ('img_desc2', '<img src="'.gf_getImage('desc_on').'" border="0">');
+                $topiclisting->set_var ('img_desc2', '<img alt="" src="'.gf_getImage('desc_on').'" style="border:none;"' . XHTML . '>');
             }
             break;
         case 3:
-            if($order == 0) {
+            if ($order == 0) {
                 $sortOrder = "replies ASC";
-                $topiclisting->set_var ('img_asc3', '<img src="'.gf_getImage('asc_on').'" border="0">');
+                $topiclisting->set_var ('img_asc3', '<img alt="" src="'.gf_getImage('asc_on').'" style="border:none;"' . XHTML . '>');
             } else {
                 $sortOrder = "replies DESC";
-                $topiclisting->set_var ('img_desc3', '<img src="'.gf_getImage('desc_on').'" border="0">');
+                $topiclisting->set_var ('img_desc3', '<img alt="" src="'.gf_getImage('desc_on').'" style="border:none;"' . XHTML . '>');
             }
             break;
         case 4:
-            if($order == 0) {
+            if ($order == 0) {
                 $sortOrder = "name ASC";
-                $topiclisting->set_var ('img_asc4', '<img src="'.gf_getImage('asc_on').'" border="0">');
+                $topiclisting->set_var ('img_asc4', '<img alt="" src="'.gf_getImage('asc_on').'" style="border:none;"' . XHTML . '>');
             } else {
                 $sortOrder = "name DESC";
-                $topiclisting->set_var ('img_desc4', '<img src="'.gf_getImage('desc_on').'" border="0">');
+                $topiclisting->set_var ('img_desc4', '<img alt="" src="'.gf_getImage('desc_on').'" style="border:none;"' . XHTML . '>');
             }
             break;
         case 5:
-            if($order == 0) {
+            if ($order == 0) {
                 $sortOrder = "lastupdated ASC";
-                $topiclisting->set_var ('img_asc5', '<img src="' .$CONF_FORUM['imgset']. '/asc_on.gif" border="0">');
+                $topiclisting->set_var ('img_asc5', '<img alt="" src="' .$CONF_FORUM['imgset']. '/asc_on.gif" style="border:none;"' . XHTML . '>');
             } else {
                 $sortOrder = "lastupdated DESC";
-                $topiclisting->set_var ('img_desc5', '<img src="' .$CONF_FORUM['imgset']. '/desc_on.gif" border="0">');
+                $topiclisting->set_var ('img_desc5', '<img alt="" src="' .$CONF_FORUM['imgset']. '/desc_on.gif" style="border:none;"' . XHTML . '>');
             }
             break;
         default:
             $sortOrder = "lastupdated DESC";
-            $topiclisting->set_var ('img_desc5', '<img src="'.gf_getImage('desc_on').'" border="0">');
+            $topiclisting->set_var ('img_desc5', '<img alt="" src="'.gf_getImage('desc_on').'" style="border:none;"' . XHTML . '>');
             break;
     }
 
@@ -797,7 +831,7 @@ if ($forum > 0) {
     $sql .= "LEFT JOIN {$_TABLES['gf_categories']} category on category.id=forum.forum_cat ";
     $sql .= "WHERE forum.forum_id = $forum";
     $category = DB_fetchArray(DB_query($sql));
-    if($totalresults < 1) {
+    if ($totalresults < 1) {
         $LANG_MSG05 = $LANG_GF02['msg05'];
     }
     $subscribe = '';
@@ -805,18 +839,20 @@ if ($forum > 0) {
         // Check for user subscription status
         $sub_check = DB_getITEM($_TABLES['gf_watch'],"id","forum_id='$forum' AND topic_id=0 AND uid='{$_USER['uid']}'");
         if ($sub_check == '') {
-            $subscribelinkimg = '<img src="'.gf_getImage('forumnotify_on').'" border="0" align="absmiddle" alt="'.$LANG_GF01['FORUMSUBSCRIBE'].'" title="'.$LANG_GF01['FORUMSUBSCRIBE'].'">';
+            $subscribelinkimg = '<img src="'.gf_getImage('forumnotify_on').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF01['FORUMSUBSCRIBE'].'" title="'.$LANG_GF01['FORUMSUBSCRIBE'].'"' . XHTML . '>';
             $subscribelink = "{$_CONF['site_url']}/forum/index.php?op=subscribe&amp;forum=$forum";
             $topiclisting->set_var ('subscribelink', $subscribelink);
             $topiclisting->set_var ('subscribelinkimg', $subscribelinkimg);
             $topiclisting->set_var ('LANG_subscribe', $LANG_GF01['FORUMSUBSCRIBE']);
+            $topiclisting->set_var ('LANG_subscribe_state', $LANG_GF01['FORUMSUBSCRIBE_FALSE']);
             $topiclisting->parse ('subscribe_link','subscribe');
         } else {
-            $subscribelinkimg = '<img src="'.gf_getImage('forumnotify_off').'" border="0" align="absmiddle" alt="'.$LANG_GF01['FORUMUNSUBSCRIBE'].'" title="'.$LANG_GF01['FORUMUNSUBSCRIBE'].'">';
+            $subscribelinkimg = '<img src="'.gf_getImage('forumnotify_off').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF01['FORUMUNSUBSCRIBE'].'" title="'.$LANG_GF01['FORUMUNSUBSCRIBE'].'"' . XHTML . '>';
             $subscribelink = "{$_CONF['site_url']}/forum/notify.php?filter=2";
             $topiclisting->set_var ('subscribelink', $subscribelink);
             $topiclisting->set_var ('subscribelinkimg', $subscribelinkimg);
             $topiclisting->set_var ('LANG_subscribe', $LANG_GF01['FORUMUNSUBSCRIBE']);
+            $topiclisting->set_var ('LANG_subscribe_state', $LANG_GF01['FORUMSUBSCRIBE_TRUE']);
             $topiclisting->parse ('subscribe_link','subscribe');
         }
     }
@@ -835,7 +871,7 @@ if ($forum > 0) {
     $topiclisting->set_var ('LANG_newforumposts', $LANG_GF02['msg113']);
 
     if ($category['is_readonly'] == 0 OR forum_modPermission($forum,$_USER['uid'],'mod_edit')) {
-        $newtopiclinkimg = '<img src="'.gf_getImage('post_newtopic').'" border="0" align="absmiddle" alt="'.$LANG_GF01['NEWTOPIC'].'" title="'.$LANG_GF01['NEWTOPIC'].'">';
+        $newtopiclinkimg = '<img src="'.gf_getImage('post_newtopic').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF01['NEWTOPIC'].'" title="'.$LANG_GF01['NEWTOPIC'].'"' . XHTML . '>';
         $topiclisting->set_var ('LANG_newtopic', $LANG_GF01['NEWTOPIC']);
         $topiclisting->set_var('newtopiclinkimg',$newtopiclinkimg);
         $topiclisting->set_var ('newtopiclink',"{$_CONF['site_url']}/forum/createtopic.php?method=newtopic&amp;forum=$forum");
@@ -849,7 +885,7 @@ if ($forum > 0) {
 
     while ($record = DB_fetchArray($topicResults,false)) {
 
-        if(($record['replies']+1) <= $CONF_FORUM['show_posts_perpage']) {
+        if (($record['replies']+1) <= $CONF_FORUM['show_posts_perpage']) {
             $displaypageslink = "";
             $gotomsg = "";
         } else {
@@ -873,7 +909,7 @@ if ($forum > 0) {
         }
 
         // Check if user is an anonymous poster
-        if($record['uid'] > 1) {
+        if ($record['uid'] > 1) {
             $showuserlink = '<span class="replypagination">';
             $showuserlink .= "<a href=\"{$_CONF['site_url']}/users.php?mode=profile&amp;uid={$record['uid']}\">{$record['name']}";
             $showuserlink .= '</a></span>';
@@ -894,7 +930,7 @@ if ($forum > 0) {
         if ($record['last_reply_rec'] > 0) {
             $lastreplysql = DB_query("SELECT * FROM {$_TABLES['gf_topic']} WHERE id={$record['last_reply_rec']}");
             $lastreply = DB_fetchArray($lastreplysql);
-            if(strlen ($lastreply['subject']) > $CONF_FORUM['show_subject_length']){
+            if (strlen ($lastreply['subject']) > $CONF_FORUM['show_subject_length']) {
                 $lastreply['subject'] = COM_truncate($record['subject'], $CONF_FORUM['show_subject_length'], '...');
                 $lastreply['subject'] .= "...";
             }
@@ -932,47 +968,46 @@ if ($forum > 0) {
             $lsql = DB_query($sql);
             if (DB_numRows($lsql) == 0) {
                 if ($record['sticky'] == 1) {
-                    $folderimg = '<img src="'.gf_getImage('sticky_new').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg115'].'" title="'.$LANG_GF02['msg115'].'">';
+                    $folderimg = '<img src="'.gf_getImage('sticky_new').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg115'].'" title="'.$LANG_GF02['msg115'].'"' . XHTML . '>';
                 } elseif ($record['locked'] == 1) {
-                    $folderimg = '<img src="'.gf_getImage('locked_new').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg116'].'" title="'.$LANG_GF02['msg116'].'">';
+                    $folderimg = '<img src="'.gf_getImage('locked_new').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg116'].'" title="'.$LANG_GF02['msg116'].'"' . XHTML . '>';
                 } else {
-                    $folderimg = '<img src="'.gf_getImage('newposts').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg60'].'" title="'.$LANG_GF02['msg60'].'">';
+                    $folderimg = '<img src="'.gf_getImage('newposts').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg60'].'" title="'.$LANG_GF02['msg60'].'"' . XHTML . '>';
                 }
             } elseif ($record['sticky'] == 1) {
-                $folderimg = '<img src="'.gf_getImage('sticky').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg61'].'" title="'.$LANG_GF02['msg61'].'">';
+                $folderimg = '<img src="'.gf_getImage('sticky').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg61'].'" title="'.$LANG_GF02['msg61'].'"' . XHTML . '>';
             } elseif ($record['locked'] == 1) {
-                $folderimg = '<img src="'.gf_getImage('locked').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg114'].'" title="'.$LANG_GF02['msg114'].'">';
+                $folderimg = '<img src="'.gf_getImage('locked').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg114'].'" title="'.$LANG_GF02['msg114'].'"' . XHTML . '>';
             } else {
-                $folderimg = '<img src="'.gf_getImage('noposts').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg59'].'" title="'.$LANG_GF02['msg59'].'">';
+                $folderimg = '<img src="'.gf_getImage('noposts').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg59'].'" title="'.$LANG_GF02['msg59'].'"' . XHTML . '>';
             }
-
         } elseif ($record['sticky'] == 1) {
-            $folderimg = '<img src="'.gf_getImage('sticky').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg61'].'" title="'.$LANG_GF02['msg61'].'">';
+            $folderimg = '<img src="'.gf_getImage('sticky').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg61'].'" title="'.$LANG_GF02['msg61'].'"' . XHTML . '>';
         } elseif ($record['locked'] == 1) {
-            $folderimg = '<img src="'.gf_getImage('locked').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg114'].'" title="'.$LANG_GF02['msg114'].'">';
+            $folderimg = '<img src="'.gf_getImage('locked').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg114'].'" title="'.$LANG_GF02['msg114'].'"' . XHTML . '>';
         } else {
-           $folderimg = '<img src="'.gf_getImage('noposts').'" border="0" align="absmiddle" alt="'.$LANG_GF02['msg59'].'" title="'.$LANG_GF02['msg59'].'">';
+           $folderimg = '<img src="'.gf_getImage('noposts').'" style="border:none; virtical-align:middle;" alt="'.$LANG_GF02['msg59'].'" title="'.$LANG_GF02['msg59'].'"' . XHTML . '>';
         }
 
 
-        if($lastreply['uid'] > 1) {
+        if ($lastreply['uid'] > 1) {
             $lastposter = COM_getDisplayName($lastreply['uid']);
         } else {
             $lastposter = $lastreply['name'];
         }
 
-        if($record['moved'] == 1){
+        if ($record['moved'] == 1){
             $moved = "{$LANG_GF01['MOVED']}: ";
         } else {
             $moved = "";
         }
 
-        if(strlen ($record['subject']) > $CONF_FORUM['show_subject_length']) {
+        if (strlen ($record['subject']) > $CONF_FORUM['show_subject_length']) {
             $subject = COM_truncate($record['subject'], $CONF_FORUM['show_subject_length'], '...');
         } else {
             $subject = $record['subject'];
         }
-        if($record['uid'] > 1) {
+        if ($record['uid'] > 1) {
             $firstposterName = COM_getDisplayName($record['uid']);
         } else {
             $firstposterName = $record['name'];
@@ -1004,17 +1039,17 @@ if ($forum > 0) {
     $topiclisting->parse ('outline_header', 'forum_outline_header');
     $topiclisting->parse ('outline_footer', 'forum_outline_footer');
     $topiclisting->parse ('output', 'topiclisting');
-    echo $topiclisting->finish ($topiclisting->get_var('output'));
+    $display .= $topiclisting->finish ($topiclisting->get_var('output'));
 
 }
 
-BaseFooter();
+$display .= BaseFooter();
 
 // Display Common headers
-gf_siteFooter();
+$display .= gf_siteFooter();
 
-$display = ob_get_contents();
-ob_end_clean();
-echo $display;
+//$display = ob_get_contents();
+//ob_end_clean();
 
+COM_output($display);
 ?>
\ No newline at end of file
